@@ -513,6 +513,14 @@ Deletes a completed or unwanted session from the Elluminate server.
     my $session = Elive::Entity::Session->retrieve( $session_id );
     $session->delete;
 
+Note that a session, will have its deleted property immediately set to true,
+but may remain accessible for a short period of time until garbage collected.
+
+So to check for a deleted session:
+
+    my $session = Elive::Entity::Session->retrieve( $session_id ); 
+    my $session_is_deleted = !$session || $session->deleted;
+
 =cut
 
 sub delete {
@@ -655,18 +663,15 @@ L<Elive::Entity::Participant>. Each participant contains one of:
 
 =back
 
-These are dereferenced via the C<user>, C<group> or C<guest> methods.For
-example, to print the list of participants for a session:
+Each participant will contain either an C<user>, C<group> or C<guest>object
+For example, to print the list of participants for a session:
 
     my $session = Elive::Entity::Session->retrieve($session_id);
     my $participants = $session->participants;
 
     foreach my $participant (@$participants) {
 
-	my $type = $participant->type;
-
-	if (! $type)  {
-	    my $user = $participant->user;
+	if (my $user = $participant->user)  {
 	    my $loginName = $user->loginName;
 	    my $email = $user->email;
 
@@ -674,8 +679,7 @@ example, to print the list of participants for a session:
 	    print ' <'.$email.'>'
 		if $email;
 	}
-	elsif ($type == 1) {
-	    my $group = $participant->group;
+	elsif (my $group = $participant->group) {
 	    my $id = $group->groupId;
 	    my $name = $group->name;
 
@@ -683,8 +687,7 @@ example, to print the list of participants for a session:
 	    print ' <'.$name.'>'
 		if $name;
 	}
-	elsif ($type == 2) {
-	    my $guest = $participant->guest;
+	elsif (my $guest = $participant->guest) {
 	    my $loginName = $guest->loginName;
 	    my $displayName = $guest->displayName;
 
@@ -693,6 +696,7 @@ example, to print the list of participants for a session:
 		if $loginName;
 	}
 	else {
+            my $type = $participant->type;
 	    die "unknown participant type: $type"; # elm 4.x? ;-)
 	}
 
@@ -841,7 +845,7 @@ want to delete associated recordings when you delete sessions:
     $_->delete for (@$recordings);
 
 However it is often customary to keep recordings for an extended period of
-time - they will remain accessable from the C<Recordings> web page on your
+time - they will remain accessible from the C<Recordings> web page on your
 Elluminate Live! web server.
 
 For more information, please see L<Elive::Entity::Recording>.
@@ -1094,10 +1098,14 @@ The maximum number of cameras.
 
 =item * Meeting telephony is not yet supported
 
+=back
+
 Maintaining the L<Elive::Entity::Session> abstraction may involve fetches from
 several entities. This is mostly transparent, but does have some implications
 for the C<list> method:
 
+=over 4
+
 =item * You can only filter on core meeting properties (C<name>, C<start>, C<end>, C<password>, C<deleted>, C<faciltatorId>, C<privateMeeting>, C<allModerators>, C<restrictedMeeting> and C<adapter>).
 
 =item * Access to other properties requires a secondary fetch. This is done
